package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.XiaoyuanNotice;

/**
 * 校园新闻Mapper接口
 * 
 * @author boman
 * @date 2023-06-05
 */
public interface XiaoyuanNoticeMapper 
{
    /**
     * 查询校园新闻
     * 
     * @param noticeId 校园新闻主键
     * @return 校园新闻
     */
    public XiaoyuanNotice selectXiaoyuanNoticeByNoticeId(Integer noticeId);

    /**
     * 查询校园新闻列表
     * 
     * @param xiaoyuanNotice 校园新闻
     * @return 校园新闻集合
     */
    public List<XiaoyuanNotice> selectXiaoyuanNoticeList(XiaoyuanNotice xiaoyuanNotice);
    public List<XiaoyuanNotice> selectXiaoyuanNoticeMyList(XiaoyuanNotice xiaoyuanNotice);
    public List<XiaoyuanNotice> selectXiaoyuanNoticeByMyCollect(XiaoyuanNotice xiaoyuanNotice);

    /**
     * 新增校园新闻
     * 
     * @param xiaoyuanNotice 校园新闻
     * @return 结果
     */
    public int insertXiaoyuanNotice(XiaoyuanNotice xiaoyuanNotice);

    /**
     * 修改校园新闻
     * 
     * @param xiaoyuanNotice 校园新闻
     * @return 结果
     */
    public int updateXiaoyuanNotice(XiaoyuanNotice xiaoyuanNotice);

    /**
     * 删除校园新闻
     * 
     * @param noticeId 校园新闻主键
     * @return 结果
     */
    public int deleteXiaoyuanNoticeByNoticeId(Integer noticeId);

    /**
     * 批量删除校园新闻
     * 
     * @param noticeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXiaoyuanNoticeByNoticeIds(Integer[] noticeIds);
}
